@@ -10,7 +10,7 @@ class Connection:
 class StateMachine:
     def __init__(self):
         self.i = StateMachineIo()
-        self.n = StateMachineIo()
+        self.s = StateMachineIo()
         self.o = StateMachineIo()
         self.con = []
         def f(_self):
@@ -26,10 +26,10 @@ class StateMachine:
     def inner(self):
         def deco(f):
             def f2(_self):
-                f(_self.i, _self.o)
+                f(_self.i, _self.s, _self.o)
             self._step = f2
             return f2
         return deco
     def __str__(self):
-        return ' '.join([l+':'+(','.join(['{}={}'.format(k,v) for k, v in t.__dict__.items()]) if len(t.__dict__)>0 else 'None')for t,l in [(self.i,'in'),(self.n,'self'),(self.o,'out')]])
+        return ' '.join([l+':'+(','.join(['{}={}'.format(k,v) for k, v in t.__dict__.items()]) if len(t.__dict__)>0 else 'None')for t,l in [(self.i,'in'),(self.s,'self'),(self.o,'out')]])
             
\ No newline at end of file
